@@ -28,50 +28,8 @@ sub distribution {
     return $self->{distribution};
 }
 
-sub meta_merge {
-    return {
-	'meta-spec'	=> {
-	    version	=> 2,
-	},
-	no_index	=> {
-	    directory	=> [ qw{ inc t xt } ],
-	},
-	resources	=> {
-	    bugtracker	=> {
-                web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Geo-Coder-Geocoder-US',
-#                mailto  => 'wyant@cpan.org',
-            },
-	    license	=> 'http://dev.perl.org/licenses/',
-	    repository	=> {
-		type	=> 'git',
-		url	=> 'git://github.com/trwyant/perl-Geo-Coder-Geocoder-US.git',
-		web	=> 'https://github.com/trwyant/perl-Geo-Coder-Geocoder-US',
-	    },
-	},
-	x_deprecated	=> 1,
-    };
-}
-
-sub notice {
-    warn <<"EOD";
-
->>>> NOTICE <<<<\a\a\a
-
-The web site that this module in a front-end to, http://geocoder.us/,
-disappeared in late 2015. Without the web site, this module does
-nothing. Because this web site or a readonable facsimile has not not
-reappeared by mid-2016, this module IS BEING RETRACTED. See the POD for
-the detailed plan.
-
-EOD
-
-    sleep 6;
-
-    return;
-}
-
 sub requires {
-    my ( undef, @extra ) = @_;		# Invocant unused
+    my ( $self, @extra ) = @_;
 ##  if ( ! $self->distribution() ) {
 ##  }
     return +{
@@ -79,8 +37,7 @@ sub requires {
 	'LWP::UserAgent'	=> 0,
 	strict			=> 0,
 	'Text::CSV'		=> 0,
-#	'URI::Escape'		=> 0,
-	'URI'			=> 0,
+	'URI::Escape'		=> 0,
 	warnings		=> 0,
 	@extra,
     };
@@ -145,21 +102,6 @@ C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
-=head2 meta_merge
-
- use YAML;
- print Dump( $meta->meta_merge() );
-
-This method returns a reference to a hash describing the meta-data which
-has to be provided by making use of the builder's C<meta_merge>
-functionality. This includes the C<no_index> and C<resources> data.
-
-=head2 notice
-
- $meta->notice();
-
-This method displays the pending-retraction notice.
-
 =head2 requires
 
  use YAML;
@@ -204,7 +146,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2018 by Thomas R. Wyant, III
+Copyright (C) 2010-2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
